import React, { useState } from 'react';
import {
  Div,
  H2,
  Img,
  A,
  Span,
  Label,
  P,
  H3,
  Hr,
  Code
} from '@cloudflare/elements';
import { Toggle } from '@cloudflare/component-toggle';
import logoV from './assets/cf-logo-v-cmyk.png';
import logoVWhite from './assets/cf-logo-v-cmyk-white.png';
import logoH from './assets/cf-logo-h-cmyk.png';
import logoHWhite from './assets/cf-logo-h-cmyk-white.png';
import logoC from './assets/cf-logo-c.png';
import logoVSvg from './assets/cf-logo-v-cmyk.js';
import logoVWhiteSvg from './assets/cf-logo-v-cmyk-white.js';
import logoHSvg from './assets/cf-logo-h-cmyk.js';
import logoHWhiteSvg from './assets/cf-logo-h-cmyk-white.js';
import logoCSvg from './assets/cf-logo-c.js';

const layoutStyles = {
  display: 'grid',
  textAlign: 'center',
  px: 4,
  py: 5,
  style: { gridTemplateColumns: 'repeat(4, 1fr)', gridColumnGap: '16px' }
};

const dataUri = svg => {
  const blob = new Blob([svg], { type: 'image/svg+xml' });
  const url = URL.createObjectURL(blob);
  return url;
};

export default ({
  BestPractice,
  snippetScope,
  ExamplePreview,
  PropRow,
  PropTable
}) => {
  const [isDark, setIsDark] = useState(false);

  return (
    <Div>
      <H2 mt={4} mb={3}>
        Assets
      </H2>

      <BestPractice
        type="info"
        title="Make sure to follow the logo guidelines"
        description={
          <span>
            If you need to use the logomarks please make sure you are using them
            correctly, the guidelines can be found{' '}
            <A
              color="inherit"
              href="https://wiki.cfops.it/display/DES/Logo+guidelines"
            >
              here
            </A>
          </span>
        }
      />
      <Div display="flex" alignItems="center" mb={3}>
        <Label htmlFor="dark" ml="auto" mr={3} cursor="pointer">
          Toggle Dark Background
        </Label>
        <Toggle
          id="dark"
          value={isDark}
          onChange={checked => setIsDark(checked)}
        />
      </Div>
      <Div
        display="grid"
        mt={4}
        style={{ gridTemplateColumns: 'repeat(3, 1fr)', gridColumnGap: '16px' }}
      >
        <Div>
          <Div fontWeight={700} mb={2}>
            Logo
          </Div>
          <Div
            borderColor="gray.7"
            border="1px solid"
            px={4}
            mb={2}
            borderRadius={2}
            bg={isDark ? 'black' : 'white'}
          >
            <Img
              src={dataUri(isDark ? logoVWhiteSvg : logoVSvg)}
              maxWidth="100%"
              minHeight="140px"
              style={{ objectFit: 'contain' }}
            />
          </Div>
          <Div display="flex" fontWeight={700}>
            <Span mr={3}>Download</Span>
            <A
              mr={3}
              color="gray.3"
              textDecoration="none"
              download="logo-v.svg"
              href={dataUri(isDark ? logoVWhiteSvg : logoVSvg)}
            >
              SVG
            </A>
            <A
              download="logo-v.png"
              href={isDark ? logoVWhite : logoV}
              color="gray.3"
              textDecoration="none"
            >
              PNG
            </A>
          </Div>
          <A />
        </Div>
        <Div>
          <Div fontWeight={700} mb={2}>
            Inline
          </Div>
          <Div
            borderColor="gray.7"
            border="1px solid"
            px={3}
            mb={2}
            borderRadius={2}
            bg={isDark ? 'black' : 'white'}
          >
            <Img
              src={dataUri(isDark ? logoHWhiteSvg : logoHSvg)}
              maxWidth="100%"
              minHeight="140px"
              style={{ objectFit: 'contain' }}
            />
          </Div>
          <Div display="flex" fontWeight={700}>
            <Span mr={3}>Download</Span>
            <A
              mr={3}
              color="gray.3"
              textDecoration="none"
              download="logo-h.svg"
              href={dataUri(isDark ? logoHWhiteSvg : logoHSvg)}
            >
              SVG
            </A>
            <A
              download="logo-h.png"
              href={isDark ? logoHWhite : logoH}
              color="gray.3"
              textDecoration="none"
            >
              PNG
            </A>
          </Div>
          <A />
        </Div>
        <Div>
          <Div fontWeight={700} mb={2}>
            Cloud
          </Div>
          <Div
            borderColor="gray.7"
            border="1px solid"
            px={5}
            mb={2}
            borderRadius={2}
            bg={isDark ? 'black' : 'white'}
          >
            <Img
              src={dataUri(logoCSvg)}
              maxWidth="100%"
              minHeight="140px"
              style={{ objectFit: 'contain' }}
            />
          </Div>
          <Div display="flex" fontWeight={700}>
            <Span mr={3}>Download</Span>
            <A
              download="logo-c.svg"
              mr={3}
              color="gray.3"
              textDecoration="none"
              href={dataUri(logoCSvg)}
            >
              SVG
            </A>
            <A
              color="gray.3"
              textDecoration="none"
              download="logo-c.png"
              href={logoC}
            >
              PNG
            </A>
          </Div>
          <A />
        </Div>
      </Div>
      <Div mt={6}>
        <ExamplePreview
          scope={{ ...snippetScope, layoutStyles }}
          split="horizontal"
          code={`
          <Div {...layoutStyles} bg="${isDark ? 'black' : 'white'}" >
          <Logo ${isDark ? 'light' : ''} />
          <LogoInline ${isDark ? 'light' : ''} />
          <LogoCloud />
          <LogoHeader />
          </Div>
        `}
        />
      </Div>

      <P my={4}>
        <Code>LogoHeader</Code> is a responsive logo, when the screen size
        increases past <Code>55em</Code> it shows both the logotype and the
        logomark, when the screen size is less than that it will only show the
        logomark. Change the screen width to see the logo change.
      </P>

      <ExamplePreview
        scope={{ ...snippetScope, layoutStyles }}
        split="horizontal"
        code={`

          <LogoHeader />

        `}
      />

      <Hr
        my={5}
        borderTop="0px"
        borderRight="0px"
        borderLeft="0px"
        borderBottom="1px solid"
        borderColor="gray.8"
      />

      <H2>Logo props</H2>

      <Div mb={5}>
        <H3 mb={1}>Styling</H3>
        <P fontSize={2} mt={0}>
          This component doesn't support any custom styling.
        </P>
      </Div>

      <Div>
        <H3 mb={1}>Custom</H3>
        <P fontSize={2} mb={3} mt={0}>
          These props are custom to this component and are based on the{' '}
          <A
            color="inherit"
            href="https://reactjs.org/docs/components-and-props.html"
          >
            React props
          </A>{' '}
          concept.
        </P>

        <PropTable cols={['Name', 'Type', 'Default', 'Description']}>
          <PropRow
            name="light"
            type="boolean"
            defaultVal="false"
            description="When true, this changes the logo to a light version that will work on dark backgrounds"
          />
          <PropRow
            name="width"
            type="string"
            defaultVal="105px"
            description={`Allows you to change the width of the logo, this must be used in conjunction with the height prop`}
          />
          <PropRow
            name="height"
            type="string"
            defaultVal="41px"
            description={`Allows you to change the height of the logo, this must be used in conjunction with the width prop`}
          />
        </PropTable>

        <Div mt={5} mb={5}>
          <H3 mb={1}>Events</H3>
          <P fontSize={2} mb={3} mt={0}>
            This component does not support any custom events.
          </P>
        </Div>
      </Div>

      <Hr
        my={5}
        borderTop="0px"
        borderRight="0px"
        borderLeft="0px"
        borderBottom="1px solid"
        borderColor="gray.8"
      />

      <H2>LogoInline props</H2>

      <Div mb={5}>
        <H3 mb={1}>Styling</H3>
        <P fontSize={2} mt={0}>
          This component doesn't support any custom styling.
        </P>
      </Div>

      <Div>
        <H3 mb={1}>Custom</H3>
        <P fontSize={2} mb={3} mt={0}>
          These props are custom to this component and are based on the{' '}
          <A
            color="inherit"
            href="https://reactjs.org/docs/components-and-props.html"
          >
            React props
          </A>{' '}
          concept.
        </P>

        <PropTable cols={['Name', 'Type', 'Default', 'Description']}>
          <PropRow
            name="light"
            type="boolean"
            defaultVal="false"
            description="When true, this changes the logo to a light version that will work on dark backgrounds"
          />
          <PropRow
            name="width"
            type="string"
            defaultVal="200px"
            description={`Allows you to change the width of the logo, this must be used in conjunction with the height prop`}
          />
          <PropRow
            name="height"
            type="string"
            defaultVal="46px"
            description={`Allows you to change the height of the logo, this must be used in conjunction with the width prop`}
          />
        </PropTable>

        <Div mt={5} mb={5}>
          <H3 mb={1}>Events</H3>
          <P fontSize={2} mb={3} mt={0}>
            This component does not support any custom events.
          </P>
        </Div>
      </Div>

      <Hr
        my={5}
        borderTop="0px"
        borderRight="0px"
        borderLeft="0px"
        borderBottom="1px solid"
        borderColor="gray.8"
      />

      <H2>LogoCloud props</H2>

      <Div mb={5}>
        <H3 mb={1}>Styling</H3>
        <P fontSize={2} mt={0}>
          This component doesn't support any custom styling.
        </P>
      </Div>

      <Div>
        <H3 mb={1}>Custom</H3>
        <P fontSize={2} mb={3} mt={0}>
          These props are custom to this component and are based on the{' '}
          <A
            color="inherit"
            href="https://reactjs.org/docs/components-and-props.html"
          >
            React props
          </A>{' '}
          concept.
        </P>

        <PropTable cols={['Name', 'Type', 'Default', 'Description']}>
          <PropRow
            name="width"
            type="string"
            defaultVal="80px"
            description={`Allows you to change the width of the logo, this must be used in conjunction with the height prop`}
          />
          <PropRow
            name="height"
            type="string"
            defaultVal="47px"
            description={`Allows you to change the height of the logo, this must be used in conjunction with the width prop`}
          />
        </PropTable>

        <Div mt={5} mb={5}>
          <H3 mb={1}>Events</H3>
          <P fontSize={2} mb={3} mt={0}>
            This component does not support any custom events.
          </P>
        </Div>
      </Div>

      <H2>LogoHeader props</H2>

      <Div mb={5}>
        <H3 mb={1}>Styling</H3>
        <P fontSize={2} mt={0}>
          This component doesn't support any custom styling.
        </P>
      </Div>

      <Div>
        <H3 mb={1}>Custom</H3>
        <P fontSize={2} mb={3} mt={0}>
          This component doesn't support any props.
        </P>

        <Div mt={5} mb={5}>
          <H3 mb={1}>Events</H3>
          <P fontSize={2} mb={3} mt={0}>
            This component does not support any custom events.
          </P>
        </Div>
      </Div>
    </Div>
  );
};
